==> simplelink_lowpower_f3_sdk_9_14_00_41__linux.zip: simplelink_lowpower_f3_sdk_9_14_00_41/docs/driverlib/cc27xx/driverlib/search/functions_e.js <==
var searchData=
[
  ['u32to8',['U32TO8',['../sw__poly1305-donna-32_8h.html#abb488326a7651204669fd11e027196f4',1,'sw_poly1305-donna-32.h']]],
  ['u8to32',['U8TO32',['../sw__poly1305-donna-32_8h.html#a89e4bb3dfbddaf6ff1ca16e36168c4f6',1,'sw_poly1305-donna-32.h']]],
  ['uartbusy',['UARTBusy',['../group__uart__api.html#gac3885270377de17cf40e2daa6f994fe4',1,'uart.h']]],
  ['uartcharavailable',['UARTCharAvailable',['../group__uart__api.html#ga941975faaf3833f25a71d55629b4a1fc',1,'uart.h']]],
  ['uartclearint',['UARTClearInt',['../group__uart__api.html#ga1dc0e3760de383e63cb8eb76b11f10d2',1,'uart.h']]],
  ['uartclearrxerror',['UARTClearRxError',['../group__uart__api.html#ga4e105ddf8e8cccf13acbfdad5aa64868',1,'uart.h']]],
  ['uartconfigsetexpclk',['UARTConfigSetExpClk',['../group__uart__api.html#gaa81a26fb59ae91063795ea2ac9f068ed',1,'UARTConfigSetExpClk(uint32_t base, uint32_t UARTClkFreq, uint32_t baudFreq, uint32_t config):&#160;uart.c'],['../group__uart__api.html#gaa81a26fb59ae91063795ea2ac9f068ed',1,'UARTConfigSetExpClk(uint32_t base, uint32_t UARTClkFreq, uint32_t baudFreq, uint32_t config):&#160;uart.c']]],
  ['uartdisable',['UARTDisable',['../group__uart__api.html#ga5b554f1d6649321f933af4d527abe069',1,'UARTDisable(uint32_t base):&#160;uart.c'],['../group__uart__api.html#ga5b554f1d6649321f933af4d527abe069',1,'UARTDisable(uint32_t base):&#160;uart.c']]],
  ['uartdisablects',['UARTDisableCTS',['../group__uart__api.html#ga2983a7e0508439475234996827be02ee',1,'uart.h']]],
  ['uartdisabledma',['UARTDisableDMA',['../group__uart__api.html#gab085c60a90d5b67513f28fd13c28db6f',1,'uart.h']]],
  ['uartdisablefifo',['UARTDisableFIFO',['../group__uart__api.html#gab9005904e1e1d165a83cbf9cae603490',1,'uart.h']]],
  ['uartdisableint',['UARTDisableInt',['../group__uart__api.html#gaf336fd6a0883c856e1273463ac043dfd',1,'uart.h']]],
  ['uartdisablerts',['UARTDisableRTS',['../group__uart__api.html#ga1732b1cfe0a6a9ae4e9a39be66aa4b79',1,'uart.h']]],
  ['uartenablects',['UARTEnableCTS',['../group__uart__api.html#ga330cffa35384b0fd19a96896d2de64b0',1,'uart.h']]],
  ['uartenabledma',['UARTEnableDMA',['../group__uart__api.html#gafbc6078fb35a662943e4c2bf95b065c0',1,'uart.h']]],
  ['uartenablefifo',['UARTEnableFifo',['../group__uart__api.html#ga0dc3c28bd584fcfdea6f2620013537c4',1,'uart.h']]],
  ['uartenableint',['UARTEnableInt',['../group__uart__api.html#gac8f3a305f1a7fd93ee0847b5db7b2df4',1,'uart.h']]],
  ['uartenablerts',['UARTEnableRTS',['../group__uart__api.html#gadbf84dcbbd11e4474e98053c0fbe0eea',1,'uart.h']]],
  ['uartgetchar',['UARTGetChar',['../group__uart__api.html#ga419b8e34fe9120836bde8a501de4be8c',1,'UARTGetChar(uint32_t base):&#160;uart.c'],['../group__uart__api.html#ga419b8e34fe9120836bde8a501de4be8c',1,'UARTGetChar(uint32_t base):&#160;uart.c']]],
  ['uartgetcharnonblocking',['UARTGetCharNonBlocking',['../group__uart__api.html#ga24591115bac9ee19e163b9b0ec54249f',1,'uart.h']]],
  ['uartgetrxerror',['UARTGetRxError',['../group__uart__api.html#ga930ba2f0258a018c1b72d6d67c0d6c35',1,'uart.h']]],
  ['uartintstatus',['UARTIntStatus',['../group__uart__api.html#ga1f13c9405287abd41f5350960217f017',1,'uart.h']]],
  ['uartputchar',['UARTPutChar',['../group__uart__api.html#ga6ca940906b741ce59f665b20d3ec4daa',1,'UARTPutChar(uint32_t base, uint8_t data):&#160;uart.c'],['../group__uart__api.html#ga6ca940906b741ce59f665b20d3ec4daa',1,'UARTPutChar(uint32_t base, uint8_t data):&#160;uart.c']]],
  ['uartputcharnonblocking',['UARTPutCharNonBlocking',['../group__uart__api.html#gaf4d41814e17d52506d611674ce399390',1,'uart.h']]],
  ['uartsetfifolevel',['UARTSetFifoLevel',['../group__uart__api.html#gae846a8eda1340a4fc4e420c63b9381c8',1,'uart.h']]],
  ['uartspaceavailable',['UARTSpaceAvailable',['../group__uart__api.html#ga72380e9c54e010b4057b325ed19e9b2a',1,'uart.h']]],
  ['udmaclearchannelpriority',['uDMAClearChannelPriority',['../group__udma__api.html#ga8dde9713cf17bef8738f83bb2cbd00ae',1,'udma.h']]],
  ['udmaclearerrorstatus',['uDMAClearErrorStatus',['../group__udma__api.html#ga3644afbbdb931c4e05f9228e718dab42',1,'udma.h']]],
  ['udmaclearint',['uDMAClearInt',['../group__udma__api.html#gad9dd2604efe04b202fbd66fa7c683332',1,'udma.h']]],
  ['udmadisable',['uDMADisable',['../group__udma__api.html#gaa93ee7aa754f7c83d31fd91799d3142d',1,'udma.h']]],
  ['udmadisablechannel',['uDMADisableChannel',['../group__udma__api.html#ga537ee399ac102517a619c3c20dc88401',1,'udma.h']]],
  ['udmadisablechannelattribute',['uDMADisableChannelAttribute',['../group__udma__api.html#ga14573b8ea2f5289dea2a61acefeb0978',1,'uDMADisableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c'],['../group__udma__api.html#ga14573b8ea2f5289dea2a61acefeb0978',1,'uDMADisableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c']]],
  ['udmadisablesweventint',['uDMADisableSwEventInt',['../group__udma__api.html#ga3da54c97f2000a628c74941e6a95a185',1,'udma.h']]],
  ['udmaenable',['uDMAEnable',['../group__udma__api.html#gaade7ecb9542da907f7075663afcb0f2c',1,'udma.h']]],
  ['udmaenablechannel',['uDMAEnableChannel',['../group__udma__api.html#gacc38805d2973c9dd47f3a288adcdf555',1,'udma.h']]],
  ['udmaenablechannelattribute',['uDMAEnableChannelAttribute',['../group__udma__api.html#ga252cd150d7b2e013f4e6afabbfa62ed9',1,'uDMAEnableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c'],['../group__udma__api.html#ga252cd150d7b2e013f4e6afabbfa62ed9',1,'uDMAEnableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c']]],
  ['udmaenablesweventint',['uDMAEnableSwEventInt',['../group__udma__api.html#ga81bba85e8c293acd6c7cf4097dd0345e',1,'udma.h']]],
  ['udmagetchannelattribute',['uDMAGetChannelAttribute',['../group__udma__api.html#gacdf16c51c8bb65f8c8c3bb8c9704cc5e',1,'uDMAGetChannelAttribute(uint32_t channelBitMask):&#160;udma.c'],['../group__udma__api.html#gacdf16c51c8bb65f8c8c3bb8c9704cc5e',1,'uDMAGetChannelAttribute(uint32_t channelBitMask):&#160;udma.c']]],
  ['udmagetchannelmode',['uDMAGetChannelMode',['../group__udma__api.html#ga679bafdef8d1a839e87e985f41c4d50b',1,'uDMAGetChannelMode(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c'],['../group__udma__api.html#ga679bafdef8d1a839e87e985f41c4d50b',1,'uDMAGetChannelMode(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c']]],
  ['udmagetchannelpriority',['uDMAGetChannelPriority',['../group__udma__api.html#ga2af2453ee66412bfb81df8723d6534e5',1,'udma.h']]],
  ['udmagetchannelsize',['uDMAGetChannelSize',['../group__udma__api.html#ga7ea1f75e8d74bd8f19d8e1c678b80daf',1,'uDMAGetChannelSize(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c'],['../group__udma__api.html#ga7ea1f75e8d74bd8f19d8e1c678b80daf',1,'uDMAGetChannelSize(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c']]],
  ['udmagetcontrolalternatebase',['uDMAGetControlAlternateBase',['../group__udma__api.html#ga47943c3c141c509b472e6a91cdeee698',1,'udma.h']]],
  ['udmagetcontrolbase',['uDMAGetControlBase',['../group__udma__api.html#gaea33f3f257ffdbe3c5edebd0b1eb3674',1,'udma.h']]],
  ['udmageterrorstatus',['uDMAGetErrorStatus',['../group__udma__api.html#gacc3fcc8a1bb42661efc226c07cf2dcf4',1,'udma.h']]],
  ['udmagetstatus',['uDMAGetStatus',['../group__udma__api.html#gab2c1bae65cbdb139c713c08b115d5b54',1,'udma.h']]],
  ['udmaintstatus',['uDMAIntStatus',['../group__udma__api.html#gaba15c1714cde0cb13a0f573e6b8bb30c',1,'udma.h']]],
  ['udmaischannelenabled',['uDMAIsChannelEnabled',['../group__udma__api.html#gacda01b11afea5b0e9f16f02904900938',1,'udma.h']]],
  ['udmaregisterint',['uDMARegisterInt',['../group__udma__api.html#ga65e04cea3a72d44e3d1eb039d68df8f1',1,'udma.h']]],
  ['udmarequestchannel',['uDMARequestChannel',['../group__udma__api.html#gae76391d0c7bced8dc0f4ee703546983b',1,'udma.h']]],
  ['udmasetchannelcontrol',['uDMASetChannelControl',['../group__udma__api.html#ga8ef4efb8c48e8b29cd826d6540107362',1,'uDMASetChannelControl(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t control):&#160;udma.c'],['../group__udma__api.html#ga8ef4efb8c48e8b29cd826d6540107362',1,'uDMASetChannelControl(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t control):&#160;udma.c']]],
  ['udmasetchannelpriority',['uDMASetChannelPriority',['../group__udma__api.html#ga22c91f6cc729ac94961e32f1d099f602',1,'udma.h']]],
  ['udmasetchanneltransfer',['uDMASetChannelTransfer',['../group__udma__api.html#ga9b4e7d22fc119452bde3edcc651b6765',1,'uDMASetChannelTransfer(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t mode, void *pSrcAddr, void *pDstAddr, uint32_t transferSize):&#160;udma.c'],['../group__udma__api.html#ga9b4e7d22fc119452bde3edcc651b6765',1,'uDMASetChannelTransfer(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t mode, void *pSrcAddr, void *pDstAddr, uint32_t transferSize):&#160;udma.c']]],
  ['udmasetcontrolbase',['uDMASetControlBase',['../group__udma__api.html#gad6118e044d7fc40e5af9ff78cdeea7b7',1,'udma.h']]],
  ['udmaunregisterint',['uDMAUnregisterInt',['../group__udma__api.html#gabbeea821b8e1c94cf98c37e903249e2e',1,'udma.h']]],
  ['ullsync',['ULLSync',['../group__ull__api.html#ga648c33de712d1bd851376540e294bfca',1,'ull.h']]]
];

==> simplelink_lowpower_f3_sdk_9_14_01_16__linux.zip: simplelink_lowpower_f3_sdk_9_14_01_16/docs/driverlib/cc27xx/driverlib/search/functions_e.js <==
var searchData=
[
  ['u32to8',['U32TO8',['../sw__poly1305-donna-32_8h.html#abb488326a7651204669fd11e027196f4',1,'sw_poly1305-donna-32.h']]],
  ['u8to32',['U8TO32',['../sw__poly1305-donna-32_8h.html#a89e4bb3dfbddaf6ff1ca16e36168c4f6',1,'sw_poly1305-donna-32.h']]],
  ['uartbusy',['UARTBusy',['../group__uart__api.html#gac3885270377de17cf40e2daa6f994fe4',1,'uart.h']]],
  ['uartcharavailable',['UARTCharAvailable',['../group__uart__api.html#ga941975faaf3833f25a71d55629b4a1fc',1,'uart.h']]],
  ['uartclearint',['UARTClearInt',['../group__uart__api.html#ga1dc0e3760de383e63cb8eb76b11f10d2',1,'uart.h']]],
  ['uartclearrxerror',['UARTClearRxError',['../group__uart__api.html#ga4e105ddf8e8cccf13acbfdad5aa64868',1,'uart.h']]],
  ['uartconfigsetexpclk',['UARTConfigSetExpClk',['../group__uart__api.html#gaa81a26fb59ae91063795ea2ac9f068ed',1,'UARTConfigSetExpClk(uint32_t base, uint32_t UARTClkFreq, uint32_t baudFreq, uint32_t config):&#160;uart.c'],['../group__uart__api.html#gaa81a26fb59ae91063795ea2ac9f068ed',1,'UARTConfigSetExpClk(uint32_t base, uint32_t UARTClkFreq, uint32_t baudFreq, uint32_t config):&#160;uart.c']]],
  ['uartdisable',['UARTDisable',['../group__uart__api.html#ga5b554f1d6649321f933af4d527abe069',1,'UARTDisable(uint32_t base):&#160;uart.c'],['../group__uart__api.html#ga5b554f1d6649321f933af4d527abe069',1,'UARTDisable(uint32_t base):&#160;uart.c']]],
  ['uartdisablects',['UARTDisableCTS',['../group__uart__api.html#ga2983a7e0508439475234996827be02ee',1,'uart.h']]],
  ['uartdisabledma',['UARTDisableDMA',['../group__uart__api.html#gab085c60a90d5b67513f28fd13c28db6f',1,'uart.h']]],
  ['uartdisablefifo',['UARTDisableFIFO',['../group__uart__api.html#gab9005904e1e1d165a83cbf9cae603490',1,'uart.h']]],
  ['uartdisableint',['UARTDisableInt',['../group__uart__api.html#gaf336fd6a0883c856e1273463ac043dfd',1,'uart.h']]],
  ['uartdisablelin',['UARTDisableLIN',['../group__uart__api.html#gababb7d232baa6115b0734ed9fa86cdd1',1,'uart.h']]],
  ['uartdisablelinbreaksync',['UARTDisableLINBreakSync',['../group__uart__api.html#ga04b64d1aa69aa85b66d7c77b34d84d26',1,'uart.h']]],
  ['uartdisablelindormant',['UARTDisableLINDormant',['../group__uart__api.html#gabe3937ad2648f25eb338e0d03168878f',1,'uart.h']]],
  ['uartdisablerts',['UARTDisableRTS',['../group__uart__api.html#ga1732b1cfe0a6a9ae4e9a39be66aa4b79',1,'uart.h']]],
  ['uartenablects',['UARTEnableCTS',['../group__uart__api.html#ga330cffa35384b0fd19a96896d2de64b0',1,'uart.h']]],
  ['uartenabledma',['UARTEnableDMA',['../group__uart__api.html#gafbc6078fb35a662943e4c2bf95b065c0',1,'uart.h']]],
  ['uartenablefifo',['UARTEnableFifo',['../group__uart__api.html#ga0dc3c28bd584fcfdea6f2620013537c4',1,'uart.h']]],
  ['uartenableint',['UARTEnableInt',['../group__uart__api.html#gac8f3a305f1a7fd93ee0847b5db7b2df4',1,'uart.h']]],
  ['uartenablelin',['UARTEnableLIN',['../group__uart__api.html#ga7e795c011470b1967bb98fa1e6bb6fb2',1,'uart.h']]],
  ['uartenablelinbreaksync',['UARTEnableLINBreakSync',['../group__uart__api.html#gaf7ac0c9301044466214e90df07c2f3cd',1,'uart.h']]],
  ['uartenablelindormant',['UARTEnableLINDormant',['../group__uart__api.html#ga0747511520dfff5759e12e811b2ae4c4',1,'uart.h']]],
  ['uartenablerts',['UARTEnableRTS',['../group__uart__api.html#gadbf84dcbbd11e4474e98053c0fbe0eea',1,'uart.h']]],
  ['uartgetchar',['UARTGetChar',['../group__uart__api.html#ga419b8e34fe9120836bde8a501de4be8c',1,'UARTGetChar(uint32_t base):&#160;uart.c'],['../group__uart__api.html#ga419b8e34fe9120836bde8a501de4be8c',1,'UARTGetChar(uint32_t base):&#160;uart.c']]],
  ['uartgetcharnonblocking',['UARTGetCharNonBlocking',['../group__uart__api.html#ga24591115bac9ee19e163b9b0ec54249f',1,'uart.h']]],
  ['uartgetrxerror',['UARTGetRxError',['../group__uart__api.html#ga930ba2f0258a018c1b72d6d67c0d6c35',1,'uart.h']]],
  ['uartintstatus',['UARTIntStatus',['../group__uart__api.html#ga1f13c9405287abd41f5350960217f017',1,'uart.h']]],
  ['uartputchar',['UARTPutChar',['../group__uart__api.html#ga6ca940906b741ce59f665b20d3ec4daa',1,'UARTPutChar(uint32_t base, uint8_t data):&#160;uart.c'],['../group__uart__api.html#ga6ca940906b741ce59f665b20d3ec4daa',1,'UARTPutChar(uint32_t base, uint8_t data):&#160;uart.c']]],
  ['uartputcharnonblocking',['UARTPutCharNonBlocking',['../group__uart__api.html#gaf4d41814e17d52506d611674ce399390',1,'uart.h']]],
  ['uartsetfifolevel',['UARTSetFifoLevel',['../group__uart__api.html#gae846a8eda1340a4fc4e420c63b9381c8',1,'uart.h']]],
  ['uartsetlindelimiterlength',['UARTSetLINDelimiterLength',['../group__uart__api.html#ga004372895f99c694026fb79cae97b0d8',1,'UARTSetLINDelimiterLength(uint32_t base, uint32_t length):&#160;uart.c'],['../group__uart__api.html#ga004372895f99c694026fb79cae97b0d8',1,'UARTSetLINDelimiterLength(uint32_t base, uint32_t length):&#160;uart.c']]],
  ['uartspaceavailable',['UARTSpaceAvailable',['../group__uart__api.html#ga72380e9c54e010b4057b325ed19e9b2a',1,'uart.h']]],
  ['udmaclearchannelpriority',['uDMAClearChannelPriority',['../group__udma__api.html#ga8dde9713cf17bef8738f83bb2cbd00ae',1,'udma.h']]],
  ['udmaclearerrorstatus',['uDMAClearErrorStatus',['../group__udma__api.html#ga3644afbbdb931c4e05f9228e718dab42',1,'udma.h']]],
  ['udmaclearint',['uDMAClearInt',['../group__udma__api.html#gad9dd2604efe04b202fbd66fa7c683332',1,'udma.h']]],
  ['udmadisable',['uDMADisable',['../group__udma__api.html#gaa93ee7aa754f7c83d31fd91799d3142d',1,'udma.h']]],
  ['udmadisablechannel',['uDMADisableChannel',['../group__udma__api.html#ga537ee399ac102517a619c3c20dc88401',1,'udma.h']]],
  ['udmadisablechannelattribute',['uDMADisableChannelAttribute',['../group__udma__api.html#ga14573b8ea2f5289dea2a61acefeb0978',1,'uDMADisableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c'],['../group__udma__api.html#ga14573b8ea2f5289dea2a61acefeb0978',1,'uDMADisableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c']]],
  ['udmadisablesweventint',['uDMADisableSwEventInt',['../group__udma__api.html#ga3da54c97f2000a628c74941e6a95a185',1,'udma.h']]],
  ['udmaenable',['uDMAEnable',['../group__udma__api.html#gaade7ecb9542da907f7075663afcb0f2c',1,'udma.h']]],
  ['udmaenablechannel',['uDMAEnableChannel',['../group__udma__api.html#gacc38805d2973c9dd47f3a288adcdf555',1,'udma.h']]],
  ['udmaenablechannelattribute',['uDMAEnableChannelAttribute',['../group__udma__api.html#ga252cd150d7b2e013f4e6afabbfa62ed9',1,'uDMAEnableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c'],['../group__udma__api.html#ga252cd150d7b2e013f4e6afabbfa62ed9',1,'uDMAEnableChannelAttribute(uint32_t channelBitMask, uint32_t attr):&#160;udma.c']]],
  ['udmaenablesweventint',['uDMAEnableSwEventInt',['../group__udma__api.html#ga81bba85e8c293acd6c7cf4097dd0345e',1,'udma.h']]],
  ['udmagetchannelattribute',['uDMAGetChannelAttribute',['../group__udma__api.html#gacdf16c51c8bb65f8c8c3bb8c9704cc5e',1,'uDMAGetChannelAttribute(uint32_t channelBitMask):&#160;udma.c'],['../group__udma__api.html#gacdf16c51c8bb65f8c8c3bb8c9704cc5e',1,'uDMAGetChannelAttribute(uint32_t channelBitMask):&#160;udma.c']]],
  ['udmagetchannelmode',['uDMAGetChannelMode',['../group__udma__api.html#ga679bafdef8d1a839e87e985f41c4d50b',1,'uDMAGetChannelMode(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c'],['../group__udma__api.html#ga679bafdef8d1a839e87e985f41c4d50b',1,'uDMAGetChannelMode(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c']]],
  ['udmagetchannelpriority',['uDMAGetChannelPriority',['../group__udma__api.html#ga2af2453ee66412bfb81df8723d6534e5',1,'udma.h']]],
  ['udmagetchannelsize',['uDMAGetChannelSize',['../group__udma__api.html#ga7ea1f75e8d74bd8f19d8e1c678b80daf',1,'uDMAGetChannelSize(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c'],['../group__udma__api.html#ga7ea1f75e8d74bd8f19d8e1c678b80daf',1,'uDMAGetChannelSize(volatile uDMAControlTableEntry const *pChannelControlStruct):&#160;udma.c']]],
  ['udmagetcontrolalternatebase',['uDMAGetControlAlternateBase',['../group__udma__api.html#ga47943c3c141c509b472e6a91cdeee698',1,'udma.h']]],
  ['udmagetcontrolbase',['uDMAGetControlBase',['../group__udma__api.html#gaea33f3f257ffdbe3c5edebd0b1eb3674',1,'udma.h']]],
  ['udmageterrorstatus',['uDMAGetErrorStatus',['../group__udma__api.html#gacc3fcc8a1bb42661efc226c07cf2dcf4',1,'udma.h']]],
  ['udmagetstatus',['uDMAGetStatus',['../group__udma__api.html#gab2c1bae65cbdb139c713c08b115d5b54',1,'udma.h']]],
  ['udmaintstatus',['uDMAIntStatus',['../group__udma__api.html#gaba15c1714cde0cb13a0f573e6b8bb30c',1,'udma.h']]],
  ['udmaischannelenabled',['uDMAIsChannelEnabled',['../group__udma__api.html#gacda01b11afea5b0e9f16f02904900938',1,'udma.h']]],
  ['udmaregisterint',['uDMARegisterInt',['../group__udma__api.html#ga65e04cea3a72d44e3d1eb039d68df8f1',1,'udma.h']]],
  ['udmarequestchannel',['uDMARequestChannel',['../group__udma__api.html#gae76391d0c7bced8dc0f4ee703546983b',1,'udma.h']]],
  ['udmasetchannelcontrol',['uDMASetChannelControl',['../group__udma__api.html#ga8ef4efb8c48e8b29cd826d6540107362',1,'uDMASetChannelControl(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t control):&#160;udma.c'],['../group__udma__api.html#ga8ef4efb8c48e8b29cd826d6540107362',1,'uDMASetChannelControl(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t control):&#160;udma.c']]],
  ['udmasetchannelpriority',['uDMASetChannelPriority',['../group__udma__api.html#ga22c91f6cc729ac94961e32f1d099f602',1,'udma.h']]],
  ['udmasetchanneltransfer',['uDMASetChannelTransfer',['../group__udma__api.html#ga9b4e7d22fc119452bde3edcc651b6765',1,'uDMASetChannelTransfer(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t mode, void *pSrcAddr, void *pDstAddr, uint32_t transferSize):&#160;udma.c'],['../group__udma__api.html#ga9b4e7d22fc119452bde3edcc651b6765',1,'uDMASetChannelTransfer(volatile uDMAControlTableEntry *pChannelControlStruct, uint32_t mode, void *pSrcAddr, void *pDstAddr, uint32_t transferSize):&#160;udma.c']]],
  ['udmasetcontrolbase',['uDMASetControlBase',['../group__udma__api.html#gad6118e044d7fc40e5af9ff78cdeea7b7',1,'udma.h']]],
  ['udmaunregisterint',['uDMAUnregisterInt',['../group__udma__api.html#gabbeea821b8e1c94cf98c37e903249e2e',1,'udma.h']]],
  ['ullsync',['ULLSync',['../group__ull__api.html#ga648c33de712d1bd851376540e294bfca',1,'ull.h']]]
];
